from collectd_rest import models, serializers, renderers
from rest_framework import viewsets
from rest_framework.renderers import JSONRenderer
from rest_framework.decorators import detail_route
from rest_framework.settings import api_settings
from django.http import HttpResponse

class GraphGroupViewSet(viewsets.ModelViewSet):
	queryset = models.GraphGroup.objects.all()
	serializer_class = serializers.GraphGroupSerializer
	lookup_field = 'name'

class GraphViewSet(viewsets.ModelViewSet):
	queryset = models.Graph.objects.all()
	serializer_class = serializers.GraphSerializer
	renderer_classes = api_settings.DEFAULT_RENDERER_CLASSES + [renderers.PNGRenderer, ]
	lookup_field = 'name'



from django.core.urlresolvers import reverse
from django.test import TestCase
from rest_framework import status
from rest_framework.test import APIClient
from collectd_rest.models import Graph, GraphGroup
from unittest.mock import patch, create_autospec
import collectd_rest.models

class GraphTest(TestCase):
	def setUp(self):
		self.client = APIClient()

	@patch('collectd_rest.models.render')
	def test_graph_create(self, mock):
		command = 'format'
		format = 'PNG'

		url = reverse('graph-list')
		group = GraphGroup.objects.create(name="group1", title="Group 1")
		response = self.client.post(url, {
			'title': 'New Graph',
			'name': 'graph1',
			'group': group.pk,
			'command': command}, format='json')
		self.assertEqual(response.status_code, status.HTTP_201_CREATED)
		graph = Graph.objects.get(name='graph1')
		mock.assert_called_with(command, format)
